<?php
/**
* @package zoolJoomLibs.mediaImageChooser
* @license    GNU/GPL
* @author Bisyarin Artyom
* @copyright Zool! Unix Workshop ({@link http://zool.in.ua})
*/

defined('_JEXEC') or die( 'Restricted access' );

// with this behavior will be available to JHTML:
JHTML::addIncludePath(dirname(__FILE__) . DS . substr_replace(basename(__FILE__), "", -4));

/**
* This is an extension for developers that allows users of your application to choose
* images in HTML Forms with Joomla's Media Manager.
*
* Installation:
*  - install zoolJoomLibs.Base plugin and publish it
*  - install zoolJoomLibs.mediaImageChooser plugin (publishing is not necessary)
*
* Usage:
*
* At first import zoolJoomLibs.Base plugin:
* <code>
* if (!JPluginHelper::importPlugin('zoolJoomLibs', 'base')) {
*     JError::raiseError(2001, 'Please, install and publish </b>zoolJoomLibs.Base</b> first.');
* }
* </code>
*
* Import mediaImageChooser class:
* <code>
* if(!zjl_import('mediaImageChooser')) {
*     JError::raiseError(2001, 'Please, install <b>zoolJoomLibs.mediaImageChooser</b> first.');
* }
* </code>
*
* Then add behavior for mediaImageChooser on your page:
* <code>JHTML::_('mediaImageChooser.behavior.all');</code>
*
* or, with custom blank image:
* <code>JHTML::_('mediaImageChooser.behavior.all', '/path/to/blank/image.png');</code>
*
* Also don't forget to add "modal" behavior:
* <code>JHTML::_('behavior.modal');</code>
*
* After that you are ready to use this class:
* <code>
* // ...
* // Start of a form goes above
* // ...
* $image_chooser = new mediaImageChooser('form_var_name', 'path/to/current/image.png');
* // Show the inputbox
* echo $image_chooser->inputBox();
* // Show the "browse button"
* echo $image_chooser->button();
* // Show the image preview box
* echo $image_chooser->imagePreview();
* // Output javascript that prepares all elements for work
* echo $image_chooser->start();
* //...
* // The rest of a form goes below
* // ...
* </code>
* 
* @package zoolJoomLibs.mediaImageChooser
* @author Bisyarin Artyom
* @copyright Zool! Unix Workshop ({@link http://zool.in.ua})
*/
class mediaImageChooser extends JObject {
/**
* Input box id.
* @access private
*/
var $boxId = '';

/**
* Current path to choosed image.
* @access private
*/
var $imgInitPath = '';

/**
* Input box id. Generated at execution time.
* @access private
*/
var $btnId = '';

/**
* Image id. Generated at execution time.
* @access private
*/
var $imgId = '';

/**
* Various stuff for inputbox element.
*/
var $boxDefs = array ('class'=>'inputbox', 'type'=>'text', 'size'=>60, 'maxlength'=>255);

/**
* Various stuff for button element.
*/
var $btnDefs = array ('sfx'=>'btn', 'win_width'=>570, 'win_height'=>400);

/**
* Various stuff for img element.
*/
var $imgDefs = array ('sfx'=>'img', 'width'=>'100', 'height'=>'100', 'border'=>'2', 'alt'=>'Preview');

/**
* @param string $id          Chooser's id (your form's input box name and id)
* @param string $imgInitPath Path to the image (empty by default)
*/
function __construct($id, $imgInitPath = '') {
    $this->imgPath = $imgInitPath;
    $this->boxId = $id;
    $this->btnId = $this->boxId . '_' . $this->btnDefs['sfx'];
    $this->imgId = $this->boxId . '_' . $this->imgDefs['sfx'];
}
/**
* Generates html code for an inputbox.
*
* @param array   $attr      Any custom attributes to "input" element, except: onchange, id, name and value
* @return string $html
*/
function inputBox($attr = array()) {
    $attr['onchange'] = "javascript:inputBoxAndImgSync(this.id, '{$this->imgId}');";
    $attr['name'] = $this->boxId;
    $attr['id']   = $this->boxId;
    $attr['value']   = $this->imgPath;

    // Default attributes handling
    foreach (array('class', 'type', 'size', 'maxlength') as $a) {
        if (empty($attr[$a])) $attr[$a] = $this->boxDefs[$a];
    }

    $attribs = JArrayHelper::toString( $attr );

    $html = "<input $attribs />";
    return $html;
}

/**
* Generates html for an image chooser button. 
*
* @param array   $attr      Any custom attributes to "a" element, except: class, href, id, name and rel
* @param numeric $winWidth  Width of modal window which opens when the button clicked
* @param numeric $winHeight Height of modal window which opens when the button clicked
* @return string $html
*/
function button($attr = array(), $winWidth = null, $winHeight = null) {
    $attr['class'] = 'modal';
    $attr['href'] = 'index.php?option=com_media&amp;view=images&amp;tmpl=component&amp;e_name=' . $this->boxId;
    $attr['id']   = $this->btnId;
    $attr['name'] = $this->btnId;
    if (is_null($winWidth)  && !is_numeric($winWidth))  $winWidth  = $this->btnDefs['win_width'];
    if (is_null($winHeight) && !is_numeric($winHeight)) $winHeight = $this->btnDefs['win_height'];
    $attr['rel']  = "{handler: 'iframe', size: {x: $winWidth, y: $winHeight}}";

    $attribs = JArrayHelper::toString( $attr );

$html = <<<EOF
<div class="button2-left">
    <div class="image">
        <a $attribs></a>
    </div>
</div>
EOF;
    return $html;
}

/**
* Generates html for an image preview element.
*
* @param array   $attr      Any custom attributes to "img" element, except: id and name.
*                           The "alt" attribute passes through JText::_()
* @return string $html
*/
function imagePreview($attr=array()) {
    $attr['id']   = $this->imgId;
    $attr['name'] = $this->imgId;

    // Default attributes handling
    foreach (array('width', 'height', 'border', 'alt') as $a) {
        if (empty($attr[$a])) $attr[$a] = $this->imgDefs[$a];
    }

    $attr['alt'] = JText::_($attr['alt']);

    $attribs = JArrayHelper::toString( $attr );

    $html = "<img $attribs />";

    return $html;
}

/**
* This method outputs javascript which prepares all elements for working together.
* Run this after creating all needed elements.
*
* @return string $html
*/
function start() {
$html = <<<EOF

<script language='javascript'>
    inputBoxAndImgSync('{$this->boxId}', '{$this->imgId}');
</script>

EOF;

return $html;
}
}